"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signTypedData = signTypedData;
const viem_1 = require("viem");
const actions_1 = require("viem/actions");
const utils_1 = require("viem/utils");
const AGWAccount_js_1 = require("../abis/AGWAccount.js");
const constants_js_1 = require("../constants.js");
const getAgwTypedSignature_js_1 = require("../getAgwTypedSignature.js");
const utils_js_1 = require("../utils.js");
const sendPrivyTransaction_js_1 = require("./sendPrivyTransaction.js");
async function signTypedData(client, signerClient, parameters, isPrivyCrossApp = false) {
    if (isPrivyCrossApp)
        return await (0, sendPrivyTransaction_js_1.sendPrivySignTypedData)(client, parameters);
    if ((0, utils_js_1.isEip712TypedData)(parameters)) {
        const rawSignature = await (0, actions_1.signTypedData)(signerClient, parameters);
        const hookData = [];
        const validationHooks = await (0, utils_1.getAction)(client, actions_1.readContract, 'readContract')({
            address: client.account.address,
            abi: AGWAccount_js_1.default,
            functionName: 'listHooks',
            args: [true],
        });
        for (const _ of validationHooks) {
            hookData.push('0x');
        }
        const signature = (0, viem_1.encodeAbiParameters)((0, viem_1.parseAbiParameters)(['bytes', 'address', 'bytes[]']), [rawSignature, constants_js_1.EOA_VALIDATOR_ADDRESS, hookData]);
        return signature;
    }
    return await (0, getAgwTypedSignature_js_1.getAgwTypedSignature)({
        client,
        signer: signerClient,
        messageHash: (0, viem_1.hashTypedData)(parameters),
    });
}
//# sourceMappingURL=signTypedData.js.map